<!--
ref.xsl - XSLT style-sheet for generating an HTML reference
Copyright (C) 2002 Michael B. Allen

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-->

<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:redirect="org.apache.xalan.xslt.extensions.Redirect"
	extension-element-prefixes="redirect">
<xsl:output method="html"
	encoding="ISO-8859-1"
	doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN"/>

<xsl:variable name="title-font-color">#006666</xsl:variable>

<xsl:template match="/">
	<xsl:apply-templates select="package"/>
</xsl:template>

<xsl:template match="package">

	<html>
	<head>
	<title><xsl:value-of select="title"/></title>
	</head>
	<frameset cols="250,*">
		<frame src="toc.html" name="left"/>

<redirect:write file="toc.html">
	<html>
	<head>
		<title><xsl:value-of select="title"/></title>
	</head>
	<body bgcolor="#f5f5f5">
	<h2><font color="{$title-font-color}">Index</font></h2>

	<b><a href="overview.html" target="right">Overview</a></b><br/>
	<xsl:for-each select="interface">
		<b><a>
			<xsl:attribute name="href">
				<xsl:value-of select="@file"/>
			</xsl:attribute>
			<xsl:attribute name="target">right</xsl:attribute>
			<xsl:value-of select="@name"/>
		</a></b><br/>
		<small>
			<xsl:for-each select="group/code">
&#160;&#160;&#160;&#160;<a>
					<xsl:attribute name="href">
						<xsl:value-of select="concat(ancestor::interface/@file, '#', @name)"/>
					</xsl:attribute>
					<xsl:attribute name="target">right</xsl:attribute>
					<xsl:value-of select="title"/>
				</a><br/>
			</xsl:for-each>
			<xsl:for-each select="group/meth">
&#160;&#160;&#160;&#160;<a>
					<xsl:attribute name="href">
						<xsl:value-of select="concat(ancestor::interface/@file, '#', @name)"/>
					</xsl:attribute>
					<xsl:attribute name="target">right</xsl:attribute>
					<xsl:value-of select="concat(ancestor::interface/@name, '_', @name)"/>
				</a><br/>
			</xsl:for-each>
		</small>
	</xsl:for-each>

	</body>
	</html>
</redirect:write>

		<frame src="overview.html" name="right"/>

<redirect:write file="overview.html">
	<html>
	<head>
    <style type="text/css">
		pre { 
		    font-family: monospace;
		    border: 1px solid black;
		    white-space: pre; 
		    color: black;
		    background-color: #dfdfdf; 
		}
		table {
			border-top: 1px solid #000000;
			border-right: 1px solid #000000;
		}
		td, th {
			border-bottom: 1px solid #000000;
			border-left: 1px solid #000000;
		}
	</style>
	<title><xsl:value-of select="title"/></title>
	</head>
	<body bgcolor="#f5f5f5">
	<h1><font color="{$title-font-color}">
		<xsl:value-of select="title"/>
	</font></h1>
	<xsl:apply-templates select="desc"/>
	<hr noshade="noshade"/>
	Michael B. Allen &lt;mballen@erols.com&gt;<br/>
	Sat Mar 30 00:46:21 EST 2002
	</body>
	</html>
</redirect:write>

	</frameset>
	</html>

	<xsl:apply-templates select="interface"/>

</xsl:template>

<xsl:template match="interface">
<redirect:write select="@file">
	<html>
	<head>
    <style type="text/css">
		pre { 
		    font-family: monospace;
		    border: 1px solid black;
		    white-space: pre; 
		    color: black;
		    background-color: #dfdfdf; 
		}
		table {
			border-top: 1px solid #000000;
			border-right: 1px solid #000000;
		}
		td, th {
			border-bottom: 1px solid #000000;
			border-left: 1px solid #000000;
		}
	</style>
	<title><xsl:value-of select="title"/></title>
	</head>
	<body bgcolor="#f5f5f5">

	<h2><font color="{$title-font-color}">
		<xsl:number level="single" count="interface" format="1. "/>
		<xsl:value-of select="title"/>
	</font></h2>
	<xsl:apply-templates select="desc"/>
	<xsl:apply-templates select="group"/>

	<hr noshade="noshade"/>
	Michael B. Allen &lt;mballen@erols.com&gt;<br/>
	Sat Mar 30 00:46:21 EST 2002
	</body>
	</html>
</redirect:write>
</xsl:template>

<xsl:template match="group">
	<h3><font color="{$title-font-color}">
		<xsl:number level="multiple" count="interface|group" format="1.1. "/>
		<xsl:value-of select="title"/>
	</font></h3>
	<xsl:apply-templates select="desc"/>
	<xsl:apply-templates select="code|meth"/>
</xsl:template>

<xsl:template match="code">
	<!-- xsl:number level="multiple" count="interface|group|code" format="1.1.1 "/ -->
	<a><xsl:attribute name="name"><xsl:value-of select="title"/></xsl:attribute></a>
	<p>
	<font size="+1" color="{$title-font-color}"><b><xsl:apply-templates select="title"/></b></font><br/>
	<b>Synopsis</b>
	<pre><br/>  #include &lt;<xsl:value-of select="ancestor::interface/include"/>&gt;<xsl:value-of select="pre"/>
	</pre>
	<b>Description</b><br/>
		<xsl:apply-templates select="desc"/><br/>
	<xsl:if test="ret">
		<b>Returns</b><br/>
			<xsl:apply-templates select="ret"/><br/>
	</xsl:if>
	</p>
</xsl:template>

<xsl:template match="meth">
	<!-- xsl:number level="multiple" count="interface|group|meth" format="1.1.1 "/ -->
	<a><xsl:attribute name="name"><xsl:value-of select="@name"/></xsl:attribute></a>
	<p>
	<xsl:variable name="fn-name" select="concat(ancestor::interface/@name, '_', @name)"/><font size="+1" color="{$title-font-color}"><b>The <code><xsl:value-of select="$fn-name"/></code> function</b></font><br/>
	<b>Synopsis</b>
	<pre><br/>  #include &lt;<xsl:value-of select="ancestor::interface/include"/>&gt;<br/>
		<xsl:text>  </xsl:text><xsl:value-of select="pre"/><br/>
	</pre>
	<b>Description</b><br/>
		<xsl:apply-templates select="desc"/><br/>
	<xsl:if test="ret">
		<b>Returns</b><br/>
			<xsl:apply-templates select="ret"/><br/>
	</xsl:if>
	</p>
</xsl:template>

<xsl:template match="desc/br">
	<xsl:copy-of select="."/>
</xsl:template>

<xsl:template match="desc/p">
	<xsl:copy-of select="."/>
</xsl:template>

<xsl:template match="desc/pre">
	<pre><xsl:value-of select="."/>
	</pre>
</xsl:template>

<xsl:template match="a">
	<xsl:copy-of select="."/>
</xsl:template>

<xsl:template match="ident|tt">
	<tt>
		<xsl:apply-templates/>
	</tt>
</xsl:template>

<xsl:template match="desc/def">
	<i>
		<xsl:apply-templates/>
	</i>
</xsl:template>

<xsl:template match="examplenum">
	<xsl:number level="any" count="example" format="1. "/>
</xsl:template>

<xsl:template match="tablenum">
	<xsl:number level="any" count="table" format="1. "/>
</xsl:template>

<!--
<xsl:template match="text()">
	<xsl:value-of select="normalize-space(.)"/>
</xsl:template>
-->

<xsl:template match="example">
	<p><b>Example <xsl:number level="any" count="example" format="1. "/><xsl:apply-templates select="title"/></b></p>
	<xsl:apply-templates select="desc"/>
	<xsl:copy-of select="pre"/>
</xsl:template>

<xsl:template match="table">
	<table cellpadding="2" cellspacing="0" align="right">
		<tr><td colspan="5"><b>Table <xsl:number level="any" count="table" format="1. "/>
				<xsl:apply-templates select="desc"/></b>
		</td></tr>
		<xsl:copy-of select="tr"/>
	</table>
</xsl:template>

</xsl:stylesheet>
